lilypondfiletools.DateTimeToken
===============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.lilypond_format

.. autoattribute:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__repr__
